@@ -22,11 +22,6 @@
 #include <gdk/gdkkeysyms.h>
 
 
-/******************************************************************************
-*                                                                             *
-* ja:リスト関数群                                                             *
-*                                                                             *
-******************************************************************************/
 static void mm_list_class_init (MmListClass *klass);
 static void mm_list_init       (MmList      *list);
 static void mm_list_destroy    (GtkObject   *object);
@@ -401,6 +396,11 @@ mm_list_init (MmList *list)
 }
 
 
+/******************************************************************************
+*                                                                             *
+* ja:リスト関数群                                                             *
+*                                                                             *
+******************************************************************************/
 /*  ja:新規作成
     RET,ウィジェット                                                        */
 GtkWidget*
@@ -410,9 +410,6 @@ mm_list_new (void)
 }
 
 
-/******************************************************************************
-*                                                                             *
-******************************************************************************/
 /*  ja:項目を追加する
       list,ウィジェット
     id3tag,タグ
@@ -569,32 +566,32 @@ mm_list_search (MmList *list,
           {
             case MM_LIST_FILE:
               text = va_arg (ap, gchar *);
-              if (g_strfilecmp (id3tag->file, text) != 0)
+              if (g_strfilecmp (id3tag->file, text))
                 goto loop;
               break;
             case MM_LIST_TITLE:
               text = va_arg (ap, gchar *);
-              if (g_strcmp (id3tag->title, text) != 0)
+              if (g_strcmp (id3tag->title, text))
                 goto loop;
               break;
             case MM_LIST_ARTIST:
               text = va_arg (ap, gchar *);
-              if (g_strcmp (id3tag->artist, text) != 0)
+              if (g_strcmp (id3tag->artist, text))
                 goto loop;
               break;
             case MM_LIST_ALBUM:
               text = va_arg (ap, gchar *);
-              if (g_strcmp (id3tag->album, text) != 0)
+              if (g_strcmp (id3tag->album, text))
                 goto loop;
               break;
             case MM_LIST_YEAR:
               text = va_arg (ap, gchar *);
-              if (g_strcmp (id3tag->year, text) != 0)
+              if (g_strcmp (id3tag->year, text))
                 goto loop;
               break;
             case MM_LIST_COMMENT:
               text = va_arg (ap, gchar *);
-              if (g_strcmp (id3tag->comment, text) != 0)
+              if (g_strcmp (id3tag->comment, text))
                 goto loop;
               break;
             case MM_LIST_TRACK:
@@ -608,12 +605,12 @@ mm_list_search (MmList *list,
               break;
             case MM_LIST_GENRE:
               text = va_arg (ap, gchar *);
-              if (g_strcmp (id3tag->genre, text) != 0)
+              if (g_strcmp (id3tag->genre, text))
                 goto loop;
               break;
             case MM_LIST_CHARSET:
               text = va_arg (ap, gchar *);
-              if (g_strcasecmp (id3tag->charset, text) != 0)
+              if (g_strcasecmp (id3tag->charset, text))
                 goto loop;
           }
       loop:
@@ -634,7 +631,6 @@ mm_list_change (MmList     *list,
                 const gint  n,
                 ...)
 {
-  gpointer *tmp;
   gint c;
   GtkTreeIter iter;
   va_list ap;
@@ -646,17 +642,12 @@ mm_list_change (MmList     *list,
   va_start (ap, n);
   while ((c = va_arg (ap, gint)) >= 0)
     {
-      if (MM_LIST_ID3TAG <= c && c <= MM_LIST_CHARSET)
-        gtk_tree_model_get (GTK_TREE_MODEL (list->store), &iter, c, &tmp, -1);
       switch (c)
         {
           case MM_LIST_ID3TAG:
             {
-              gchar *str;
               ID3Tag *id3tag0;
 
-              gtk_tree_model_get (GTK_TREE_MODEL (list->store), &iter,
-                                                    MM_LIST_TRACK, &str, -1);
               id3tag0 = va_arg (ap, ID3Tag *);
               gtk_list_store_set (list->store, &iter,
                   MM_LIST_ID3TAG,  id3tag0,
@@ -672,7 +663,6 @@ mm_list_change (MmList     *list,
                   MM_LIST_GENRE,   id3tag0->genre,
                   MM_LIST_CHARSET, id3tag0->charset,
                   -1);
-              g_free (str);
               g_free (id3tag->file);
               g_free (id3tag->title);
               g_free (id3tag->artist);
@@ -681,6 +671,7 @@ mm_list_change (MmList     *list,
               g_free (id3tag->comment);
               g_free (id3tag->genre);
               g_free (id3tag->charset);
+              g_free (id3tag);
               id3tag = id3tag0;
             }
             break;
@@ -730,11 +721,7 @@ mm_list_change (MmList     *list,
             id3tag->charset = va_arg (ap, gchar *);
             gtk_list_store_set (list->store, &iter,
                                         MM_LIST_CHARSET, id3tag->charset, -1);
-            break;
-          default:
-            tmp = NULL;
         }
-      g_free (tmp);
       if (MM_LIST_ID3TAG <= c && c <= MM_LIST_CHARSET && list->signal)
         g_signal_emit_by_name (G_OBJECT (list), "edited", n, c);
     }
@@ -875,6 +862,10 @@ mm_list_swap (MmList     *list,
                                 MM_LIST_DELETE_SENSITIVE,  delete_sensitive0,
                                 MM_LIST_DELETE_TOGGLE,     delete_toggle0,
                                 -1);
+  g_free (track0);
+  g_free (track1);
+  g_free (status0);
+  g_free (status1);
   if (list->signal)
     g_signal_emit_by_name (G_OBJECT (list), "moved", n0, n1);
 }
@@ -887,15 +878,13 @@ void
 mm_list_delete (MmList     *list,
                 const gint  n)
 {
-  gchar *track;
   GtkTreeIter iter;
   ID3Tag *id3tag;
 
   gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (list->store), &iter, NULL, n);
   gtk_tree_model_get (GTK_TREE_MODEL (list->store), &iter,
-                        MM_LIST_ID3TAG, &id3tag, MM_LIST_TRACK, &track, -1);
+                                                MM_LIST_ID3TAG, &id3tag, -1);
   gtk_list_store_remove (list->store, &iter);
-  g_free (track);
   if (id3tag)
     {
       g_free (id3tag->file);
@@ -1567,7 +1556,7 @@ mm_list_is_valid_file (MmList      *list,
 {
   gint i;
 
-  if (file == NULL || file[0] == '\0'
+  if (!file || file[0] == '\0'
                 || file[g_strlen (file) - 1] == G_DIR_SEPARATOR
                 || !g_path_is_absolute (file)
                 || g_strstr (file, G_DIR_SEPARATOR_S "." G_DIR_SEPARATOR_S)
@@ -1577,6 +1566,7 @@ mm_list_is_valid_file (MmList      *list,
                         (GTK_TREE_MODEL (list->store), NULL) - 1; i >= 0; i--)
     if (n != i)
       {
+        gboolean result;
         gchar *str;
         GtkTreeIter iter;
 
@@ -1584,7 +1574,9 @@ mm_list_is_valid_file (MmList      *list,
                                                             &iter, NULL, i);
         gtk_tree_model_get (GTK_TREE_MODEL (list->store), &iter,
                                                     MM_LIST_FILE, &str, -1);
-        if (g_strfilecmp (file, str) == 0)
+        result = !g_strfilecmp (file, str);
+        g_free (str);
+        if (result)
           return FALSE;
       }
   return TRUE;
@@ -1668,6 +1660,7 @@ mm_list_set_status (MmList      *list,
                                                             &iter, NULL, n);
           gtk_tree_model_get (GTK_TREE_MODEL (list->store),
                                             &iter, MM_LIST_STATUS, &str, -1);
+          g_free (str);
           if (str)
             break;
         }
