@@ -90,32 +90,32 @@ main (int   argc,
   GtkWidget *handle, *toolbar, *vbox;
   GtkItemFactoryEntry menu_items[] = {
 {N_("/_File"),                         NULL,              NULL,            0, "<Branch>"},
-{N_("/File/_New"),                     "<control>n",      command_new,     0, "<Item>"},
-{N_("/File/_Open..."),                 "<control>o",      command_open,    0, "<Item>"},
-{N_("/File/_Close"),                   "<control>w",      command_close,   0, "<Item>"},
-{N_("/File/_Save"),                    "<control>s",      command_save,    0, "<Item>"},
+{N_("/File/_New"),                     "<control>N",      command_new,     0, "<Item>"},
+{N_("/File/_Open..."),                 "<control>O",      command_open,    0, "<Item>"},
+{N_("/File/_Close"),                   "<control>W",      command_close,   0, "<Item>"},
+{N_("/File/_Save"),                    "<control>S",      command_save,    0, "<Item>"},
 {N_("/File/Save _As..."),              NULL,              command_saveas,  0, "<Item>"},
-{N_("/File/_Reload..."),               "<control>r",      command_reload,  0, "<Item>"},
+{N_("/File/_Reload..."),               "<control>R",      command_reload,  0, "<Item>"},
 {N_("/File/Sep1"),                     NULL,              NULL,            0, "<Separator>"},
-{N_("/File/_Export..."),               "<control>e",      command_export,  0, "<Item>"},
+{N_("/File/_Export..."),               "<control>E",      command_export,  0, "<Item>"},
 {N_("/File/Sep2"),                     NULL,              NULL,            0, "<Separator>"},
-{N_("/File/E_xit"),                    "<control>q",      command_exit,    0, "<Item>"},
+{N_("/File/E_xit"),                    "<control>Q",      command_exit,    0, "<Item>"},
 {N_("/_Tag"),                          NULL,              NULL,            0, "<Branch>"},
 {N_("/Tag/_Up"),                       NULL,              command_up,      0, "<Item>"},
 {N_("/Tag/_Down"),                     NULL,              command_down,    0, "<Item>"},
 {N_("/Tag/Sep1"),                      NULL,              NULL,            0, "<Separator>"},
-{N_("/Tag/R_oot..."),                  "<control>h",      command_root,    0, "<Item>"},
+{N_("/Tag/R_oot..."),                  "<control>H",      command_root,    0, "<Item>"},
 {N_("/Tag/_Refresh..."),               "F5",              command_refresh, 0, "<Item>"},
 {N_("/Tag/A_dd..."),                   "Insert",          command_add,     0, "<Item>"},
 {N_("/Tag/_Edit..."),                  "<control>Return", command_edit,    0, "<Item>"},
-{N_("/Tag/_Search..."),                "<control>f",      command_search,  0, "<Item>"},
+{N_("/Tag/_Search..."),                "<control>F",      command_search,  0, "<Item>"},
 {N_("/Tag/Sep2"),                      NULL,              NULL,            0, "<Separator>"},
-{N_("/Tag/Cu_t"),                      "<control>x",      command_cut,     0, "<Item>"},
-{N_("/Tag/_Copy"),                     "<control>c",      command_copy,    0, "<Item>"},
-{N_("/Tag/_Paste"),                    "<control>v",      command_paste,   0, "<Item>"},
+{N_("/Tag/Cu_t"),                      "<control>X",      command_cut,     0, "<Item>"},
+{N_("/Tag/_Copy"),                     "<control>C",      command_copy,    0, "<Item>"},
+{N_("/Tag/_Paste"),                    "<control>V",      command_paste,   0, "<Item>"},
 {N_("/Tag/De_lete"),                   "Delete",          command_delete,  0, "<Item>"},
 {N_("/Tag/Sep3"),                      NULL,              NULL,            0, "<Separator>"},
-{N_("/Tag/_All"),                      "<control>a",      command_all,     0, "<Item>"},
+{N_("/Tag/_All"),                      "<control>A",      command_all,     0, "<Item>"},
 {N_("/_Option"),                       NULL,              NULL,            0, "<Branch>"},
 {N_("/Option/_Configuration..."),      NULL,              command_conf,    0, "<Item>"},
 {N_("/Option/_Genre..."),              NULL,              genre_dialog,    0, "<Item>"},
@@ -128,14 +128,14 @@ main (int   argc,
 {N_("/_Refresh..."),                   "F5",              command_refresh, 0, "<Item>"},
 {N_("/A_dd..."),                       "Insert",          command_add,     0, "<Item>"},
 {N_("/_Edit..."),                      "<control>Return", command_edit,    0, "<Item>"},
-{N_("/_Search..."),                    "<control>f",      command_search,  0, "<Item>"},
+{N_("/_Search..."),                    "<control>F",      command_search,  0, "<Item>"},
 {"/Sep1",                              NULL,              NULL,            0, "<Separator>"},
-{N_("/Cu_t"),                          "<control>x",      command_cut,     0, "<Item>"},
-{N_("/_Copy"),                         "<control>c",      command_copy,    0, "<Item>"},
-{N_("/_Paste"),                        "<control>v",      command_paste,   0, "<Item>"},
+{N_("/Cu_t"),                          "<control>X",      command_cut,     0, "<Item>"},
+{N_("/_Copy"),                         "<control>C",      command_copy,    0, "<Item>"},
+{N_("/_Paste"),                        "<control>V",      command_paste,   0, "<Item>"},
 {N_("/De_lete"),                       "Delete",          command_delete,  0, "<Item>"},
 {"/Sep2",                              NULL,              NULL,            0, "<Separator>"},
-{N_("/_All"),                          "<control>a",      command_all,     0, "<Item>"}};
+{N_("/_All"),                          "<control>A",      command_all,     0, "<Item>"}};
   /* Drag&Drop */
   GtkTargetEntry drag_types[1] = {{"text/uri-list", 0, 0}};
 
