@@ -27,13 +27,19 @@
 #endif /* G_OS_WIN32 */
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 #define MMAID_VERSION_NOTICE "Melody maid "VERSION" ("MMAID_BUILD_ENVIRONMENT")"
 #define MMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2004 Kazuki IWAMOTO"
 
 #define MENUFILE 10
 
 
-typedef struct MmaidWindow_Tag {
+typedef struct MmaidWindow_Tag
+{
   gboolean create;              /* ja:TRUE:新規作成,FALSE:既存ファイル */
   gboolean edit;                /* ja:TRUE:編集済み,FALSE:未編集 */
   gchar *charset;               /* ja:キャラクターセット */
@@ -44,7 +50,8 @@ typedef struct MmaidWindow_Tag {
   GtkWidget *mark;              /* ja:タブの編集済みマーク */
   GtkWidget *menu_item;         /* ja:メニューのウインドウの項目 */
 } MmaidWindow;
-typedef struct ID3Tag_Tag {
+typedef struct ID3Tag_Tag
+{
   gchar *file;
   gchar *title;
   gchar *artist;
@@ -57,7 +64,8 @@ typedef struct ID3Tag_Tag {
 } ID3Tag;
 
 
-enum {
+enum
+{
     TARGET_MMAID
 };
 
@@ -87,4 +95,9 @@ extern UINT uFormat;                    /* ja:クリップボード */
 #endif /* G_OS_WIN32 */
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
